// -----------------------------------------------------------------------------
//
//     MAP: Checkmate
//  AUTHOR: Julius
// LICENSE: GPLv2
//    DATE: 29-Aug-2016
//
// SHADERS: Written by Julius aka Julio César (juliocesar2k7@gmail.com)
//    DATE: 31-Aug-2016
//
// -----------------------------------------------------------------------------

//
// LIGHTS:
//  q3map_lightRGB 1 0.737254 0.250980  // light color
//  q3map_lightSubdivide 32             // a point light on the surface every <N> game units
//  q3map_surfaceLight 750              // cast light with intensity <N>
//
// LIGHTMAPS:
//  q3map_lightmapSampleSize 16         // 1 lightmap pixel for every <N> game units
//  q3map_lightmapFilterRadius 8 0      // <self> <other> (blur shadows)
//  q3map_lightmapSampleOffset 8        // used to fix splotches on lightmapped terrain
//
// MODELS:
//  q3map_forceMeta                     // use lightmaps for lighting
//  q3map_clipModel                     // autoclip for player & weapon collisions
//
// PHONG SHADING:
//  q3map_nonPlanar                     // use Phong shading for this surface
//  q3map_shadeAngle 120                // breaking angle for Phong shading (typical 120-179 range)
//                                         It is the angle at which Phong shading stops
//
// RADIOSITY:
//  q3map_bounceScale 2                 // scales up reflected light (radiosity)
//
// AMBIENT OCCLUSION:
//  q3map_noDirty                       // UNDOCUMENTED, do not apply -dirty on this surface
//
// GLOSS/SPECULAR:
//  dpGlossIntensityMod 3               // gloss intensity multiplier
//  dpGlossExponentMod 2                // gloss sharpness multiplier (gloss with alpha channel)
//
// REFLECT FX:
//  dpReflect <distortion> <R> <G> <B> <alpha>
//  The reflection is alpha blended on the texture with the given alpha and
//  modulated by the given color. Distort is used in conjunction with the normalmap.


// Base shaders (used from other shaders) --------------------------------------

textures/map_checkmate/base1
{
    q3map_lightmapSampleSize 4
    q3map_lightmapFilterRadius 8 0
}

textures/map_checkmate/base2
{
    q3map_lightmapSampleSize 4
    q3map_lightmapFilterRadius 8 0
    q3map_nonPlanar
    q3map_shadeAngle 179    // foot of models (135º and 150º between faces)
}

textures/map_checkmate/base3
{
    q3map_lightmapSampleSize 4
    q3map_lightmapFilterRadius 8 0
    q3map_nonPlanar
    q3map_shadeAngle 90     // cross of King model
}


// Base metals -----------------------------------------------------------------

textures/map_checkmate/base_met1
{
    qer_editorImage textures/map_checkmate/base/base_met1_qer.jpg

    q3map_baseShader textures/map_checkmate/base1

    dpReflectCube env/cubemap/exomorph
    dpGlossIntensityMod 1
    dpGlossExponentMod 2

    {
        map textures/map_checkmate/base/base_met1.tga
        rgbGen identity
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}

textures/map_checkmate/base_met2
{
    qer_editorImage textures/map_checkmate/base/base_met2_qer.jpg

    q3map_baseShader textures/map_checkmate/base1

    dpReflectCube env/cubemap/exomorph
    dpGlossIntensityMod 1
    dpGlossExponentMod 2

    {
        map textures/map_checkmate/base/base_met2.tga
        rgbGen identity
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}

textures/map_checkmate/base_met3
{
    qer_editorImage textures/map_checkmate/base/base_met3_qer.jpg

    q3map_baseShader textures/map_checkmate/base1

    dpReflectCube env/cubemap/exomorph
    dpGlossIntensityMod 2
    dpGlossExponentMod 4      // platic-like

    {
        map textures/map_checkmate/base/base_met3.tga
        rgbGen identity
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}

textures/map_checkmate/base_met4
{
    qer_editorImage textures/map_checkmate/base/base_met4_qer.jpg

    q3map_baseShader textures/map_checkmate/base1

    dpReflectCube env/cubemap/exomorph
    dpGlossIntensityMod 2
    dpGlossExponentMod 4      // platic-like

    {
        map textures/map_checkmate/base/base_met4.tga
        rgbGen identity
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}

textures/map_checkmate/base_pits1
{
    qer_editorImage textures/map_checkmate/base/base_pits1_qer.jpg

    q3map_baseShader textures/map_checkmate/base1

    dpGlossIntensityMod 1
    dpGlossExponentMod 0.75   // expanded gloss

    {
        map textures/map_checkmate/base/base_pits1.tga
        rgbGen identity
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}

textures/map_checkmate/base_pipe
{
    qer_editorImage textures/map_checkmate/base/base_met3_qer.jpg

    q3map_baseShader textures/map_checkmate/base1

    dpReflectCube env/cubemap/exomorph
    dpGlossIntensityMod 2
    dpGlossExponentMod 0.75   // expanded gloss

    {
        map textures/map_checkmate/base/base_met3.tga
        rgbGen identity
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}

// Phong shading versions:

textures/map_checkmate/base_met1_phong
{
    qer_editorImage textures/map_checkmate/base/base_met1_qer.jpg

    q3map_baseShader textures/map_checkmate/base2

    dpReflectCube env/cubemap/exomorph
    dpGlossIntensityMod 1
    dpGlossExponentMod 2

    {
        map textures/map_checkmate/base/base_met1.tga
        rgbGen identity
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}

textures/map_checkmate/base_met2_phong
{
    qer_editorImage textures/map_checkmate/base/base_met2_qer.jpg

    q3map_baseShader textures/map_checkmate/base2

    dpReflectCube env/cubemap/exomorph
    dpGlossIntensityMod 1
    dpGlossExponentMod 2

    {
        map textures/map_checkmate/base/base_met2.tga
        rgbGen identity
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}

textures/map_checkmate/base_met3_phong
{
    qer_editorImage textures/map_checkmate/base/base_met3_qer.jpg

    q3map_baseShader textures/map_checkmate/base3

    dpReflectCube env/cubemap/exomorph
    dpGlossIntensityMod 2
    dpGlossExponentMod 4      // platic-like

    {
        map textures/map_checkmate/base/base_met3.tga
        rgbGen identity
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}

textures/map_checkmate/base_met4_phong
{
    qer_editorImage textures/map_checkmate/base/base_met4_qer.jpg

    q3map_baseShader textures/map_checkmate/base3

    dpReflectCube env/cubemap/exomorph
    dpGlossIntensityMod 2
    dpGlossExponentMod 4      // platic-like

    {
        map textures/map_checkmate/base/base_met4.tga
        rgbGen identity
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}

textures/map_checkmate/base_pits1_phong
{
    qer_editorImage textures/map_checkmate/base/base_pits1_qer.jpg

    q3map_baseShader textures/map_checkmate/base2

    dpGlossIntensityMod 1
    dpGlossExponentMod 0.75   // expanded gloss

    {
        map textures/map_checkmate/base/base_pits1.tga
        rgbGen identity
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}


// Floor -----------------------------------------------------------------------

textures/map_checkmate/floor_clang1
{
    qer_editorImage textures/map_checkmate/floor/floor_clang1.tga

    q3map_baseShader textures/map_checkmate/base1

    surfaceparm metalsteps

    {
        map textures/map_checkmate/floor/floor_clang1.tga
        rgbGen identity
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}

textures/map_checkmate/floor_clang2
{
    qer_editorImage textures/map_checkmate/floor/floor_clang2.tga

    q3map_baseShader textures/map_checkmate/base1

    surfaceparm metalsteps

    {
        map textures/map_checkmate/floor/floor_clang2.tga
        rgbGen identity
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}

textures/map_checkmate/floor_grate1
{
    qer_editorImage textures/map_checkmate/floor/floor_grate1.tga

    dpReflectCube env/cubemap/exomorph
    dpGlossIntensityMod 2

    surfaceparm metalsteps

    {
        map textures/map_checkmate/floor/floor_grate1.tga
        rgbGen identity
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}

textures/map_checkmate/floor_grate2
{
    qer_editorImage textures/map_checkmate/floor/floor_grate2.tga

    dpReflectCube env/cubemap/exomorph
    dpGlossIntensityMod 2

    surfaceparm metalsteps

    {
        map textures/map_checkmate/floor/floor_grate2.tga
        rgbGen identity
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}

textures/map_checkmate/floor_grate3
{
    qer_editorImage textures/map_checkmate/floor/floor_grate3.tga

    dpReflectCube env/cubemap/exomorph
    dpGlossIntensityMod 2

    surfaceparm metalsteps

    {
        map textures/map_checkmate/floor/floor_grate3.tga
        rgbGen identity
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}

textures/map_checkmate/floor_grate4
{
    qer_editorImage textures/map_checkmate/floor/floor_grate4.tga

    dpReflectCube env/cubemap/exomorph
    dpGlossIntensityMod 2

    surfaceparm metalsteps

    {
        map textures/map_checkmate/floor/floor_grate4.tga
        rgbGen identity
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}


// Grate -----------------------------------------------------------------------

textures/map_checkmate/grate1
{
    qer_editorImage textures/map_checkmate/grate/grate1.tga
    qer_alphaFunc gequal 0.5

    q3map_cloneShader textures/map_checkmate/grate1_back

    dpReflectCube env/cubemap/exomorph
    dpGlossIntensityMod 3

    surfaceparm trans
    surfaceparm alphashadow
    surfaceparm metalsteps

    {
        map textures/map_checkmate/grate/grate1.tga
        rgbGen identity
        alphaFunc GT0
        depthWrite
    }
    {
        map $lightmap
        rgbGen identity
        depthFunc equal
        blendFunc filter
    }
}

textures/map_checkmate/grate1_back
{
    q3map_invert

    //dpReflectCube env/cubemap/exomorph
    //dpGlossIntensityMod 3

    surfaceparm trans

    {
        map textures/map_checkmate/grate/grate1.tga
        rgbGen identity
        alphaFunc GT0
        depthWrite
    }
    {
        map $lightmap
        rgbGen identity
        depthFunc equal
        blendFunc filter
    }
}


// Light -----------------------------------------------------------------------

textures/map_checkmate/light_trim1
{
    qer_editorImage textures/map_checkmate/light/light_trim1.tga

    dpReflectCube env/cubemap/exomorph
    dpGlossIntensityMod 2

    q3map_lightRGB 1 1 0.647058         // 255 255 165 RGB (35% sat.)
    q3map_lightSubdivide 64
    q3map_surfaceLight 125

    {
        map textures/map_checkmate/light/light_trim1.tga
        rgbGen identity
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}

textures/map_checkmate/light_trim2
{
    qer_editorImage textures/map_checkmate/light/light_trim2.tga

    dpReflectCube env/cubemap/exomorph
    dpGlossIntensityMod 1

    q3map_lightRGB 0.250980 0.635294 1  // 64 162 255 RGB (75% sat.)
    q3map_lightSubdivide 64
    q3map_surfaceLight 125

    {
        map textures/map_checkmate/light/light_trim2.tga
        rgbGen identity
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}

textures/map_checkmate/light_trim3_50
{
    qer_editorImage textures/map_checkmate/light/light_trim3.tga

    q3map_baseShader textures/map_checkmate/base1

    dpReflectCube env/cubemap/exomorph
    dpGlossIntensityMod 2
    dpGlossExponentMod 2

    q3map_lightRGB 1 0.843137 1         // 255 215 255 RGB (16% sat.)
    q3map_lightSubdivide 32
    q3map_surfaceLight 50

    {
        map textures/map_checkmate/light/light_trim3.tga
        rgbGen identity
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}

textures/map_checkmate/light_trim3_150
{
    qer_editorImage textures/map_checkmate/light/light_trim3.tga

    q3map_baseShader textures/map_checkmate/base1

    dpReflectCube env/cubemap/exomorph
    dpGlossIntensityMod 2
    dpGlossExponentMod 2

    q3map_lightRGB 1 0.843137 1         // 255 215 255 RGB (16% sat.)
    q3map_lightSubdivide 32
    q3map_surfaceLight 150

    {
        map textures/map_checkmate/light/light_trim3.tga
        rgbGen identity
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}

textures/map_checkmate/light_trim3_end
{
    qer_editorImage textures/map_checkmate/light/light_trim3end.tga

    q3map_baseShader textures/map_checkmate/base1

    dpReflectCube env/cubemap/exomorph
    dpGlossIntensityMod 2
    dpGlossExponentMod 2

    {
        map textures/map_checkmate/light/light_trim3end.tga
        rgbGen identity
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}

textures/map_checkmate/light_trim4
{
    qer_editorImage textures/map_checkmate/light/light_trim4.tga

    dpReflectCube env/cubemap/exomorph
    dpGlossIntensityMod 2
    dpGlossExponentMod 2

    q3map_lightRGB 1 0.843137 1         // 255 215 255 RGB (16% sat.)
    q3map_lightSubdivide 32
    q3map_surfaceLight 150

    {
        map textures/map_checkmate/light/light_trim4.tga
        rgbGen identity
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}


// Panels ----------------------------------------------------------------------

textures/map_checkmate/panel1
{
    qer_editorImage textures/map_checkmate/panel/panel1.tga

    dpReflectCube env/cubemap/exomorph
    dpGlossIntensityMod 1

    {
        map textures/map_checkmate/panel/panel1.tga
        rgbGen identity
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}

textures/map_checkmate/panel2
{
    qer_editorImage textures/map_checkmate/panel/panel2.tga

    dpReflectCube env/cubemap/exomorph
    dpGlossIntensityMod 1

    {
        map textures/map_checkmate/panel/panel2.tga
        rgbGen identity
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}

textures/map_checkmate/panel3
{
    qer_editorImage textures/map_checkmate/panel/panel3.tga

    dpGlossIntensityMod 2

    {
        map textures/map_checkmate/panel/panel3.tga
        rgbGen identity
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}

textures/map_checkmate/panel4
{
    qer_editorImage textures/map_checkmate/panel/panel4.tga

    dpGlossIntensityMod 2

    surfaceparm metalsteps

    {
        map textures/map_checkmate/panel/panel4.tga
        rgbGen identity
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}


// Trim ------------------------------------------------------------------------

textures/map_checkmate/trim1
{
    qer_editorImage textures/map_checkmate/trim/trim1.tga

    dpReflectCube env/cubemap/exomorph
    dpGlossIntensityMod 2

    surfaceparm metalsteps

    {
        map textures/map_checkmate/trim/trim1.tga
        rgbGen identity
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}

textures/map_checkmate/trim2
{
    qer_editorImage textures/map_checkmate/trim/trim2.tga

    //dpReflectCube env/cubemap/exomorph     // I dont like cubemapping on this trim
    dpGlossIntensityMod 3

    surfaceparm metalsteps

    {
        map textures/map_checkmate/trim/trim2.tga
        rgbGen identity
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}

textures/map_checkmate/trim3
{
    qer_editorImage textures/map_checkmate/trim/trim3.tga

    dpReflectCube env/cubemap/exomorph
    dpGlossIntensityMod 2

    surfaceparm metalsteps

    {
        map textures/map_checkmate/trim/trim3.tga
        rgbGen identity
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}

textures/map_checkmate/trim4
{
    qer_editorImage textures/map_checkmate/trim/trim4.tga

    dpReflectCube env/cubemap/exomorph
    dpGlossIntensityMod 1

    surfaceparm metalsteps

    {
        map textures/map_checkmate/trim/trim4.tga
        rgbGen identity
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}

textures/map_checkmate/trim5
{
    qer_editorImage textures/map_checkmate/trim/trim5_qer.jpg

    dpReflectCube env/cubemap/exomorph
    dpGlossIntensityMod 2

    surfaceparm metalsteps

    {
        map textures/map_checkmate/trim/trim5.tga
        rgbGen identity
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}


// Decal -----------------------------------------------------------------------

textures/map_checkmate/dec_blood
{
    qer_editorImage textures/map_checkmate/decal/dec_blood.tga
    qer_alphaFunc gequal 0.5

    surfaceparm trans
    surfaceparm nonsolid

    noPicMip             // ignore user-set values for the r_picmip cvar
    polygonOffset        // rendered slightly off the polygon's surface
    sort 6               // depth sorting of shaders

    {
        map textures/map_checkmate/decal/dec_blood.tga
        rgbGen identity
        blendFunc blend
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}

textures/map_checkmate/dec_washere
{
    qer_editorImage textures/map_checkmate/decal/dec_washere.tga
    qer_alphaFunc gequal 0.5

    surfaceparm trans
    surfaceparm nonsolid

    noPicMip
    polygonOffset
    sort 6

    {
        map textures/map_checkmate/decal/dec_washere.tga
        rgbGen identity
        blendFunc blend
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}

textures/map_checkmate/dec_xonlogo
{
    qer_editorImage textures/map_checkmate/decal/dec_xonlogo.tga
    qer_alphaFunc gequal 0.5

    surfaceparm trans
    surfaceparm nonsolid

    noPicMip
    polygonOffset
    sort 6

    {
        map textures/map_checkmate/decal/dec_xonlogo.tga
        rgbGen identity
        blendFunc blend
    }
    {
        map $lightmap
        rgbGen identity
        blendFunc filter
    }
}

// FX --------------------------------------------------------------------------

textures/map_checkmate/fx_elec_arc
{
    qer_editorImage textures/map_checkmate/fx/arc_01.jpg
    qer_trans 0.50

    deformVertexes autosprite2     // draw it always oriented to the player's view
    cull none                      // autosprite dont work without cull none

    surfaceparm trans
    surfaceparm nonsolid
    surfaceparm noimpact
    surfaceparm nodlight
    surfaceparm nolightmap

    // 11 frames animation repeated 1.82 times per second (11x1.82=20 fps)
    {
        animMap 20 textures/map_checkmate/fx/arc_01 textures/map_checkmate/fx/arc_02 textures/map_checkmate/fx/arc_03 textures/map_checkmate/fx/arc_04 textures/map_checkmate/fx/arc_05 textures/map_checkmate/fx/arc_06 textures/map_checkmate/fx/arc_07 textures/map_checkmate/fx/arc_08 textures/map_checkmate/fx/arc_09 textures/map_checkmate/fx/arc_10 textures/map_checkmate/fx/arc_11
        rgbGen identity
        blendFunc add
    }
}


// Sky -------------------------------------------------------------------------

textures/map_checkmate/sky
{
    qer_editorImage env/sky/frozendusk_preview.jpg
    skyParms env/sky/frozendusk - -

    surfaceparm sky
    surfaceparm noimpact
    surfaceparm nodlight
    surfaceparm nolightmap

    noPicMip
    noMipMaps

    // q3map_sunExt <R> <G> <B>  <intensity>  <degrees> <elevation>  <deviance> <samples>
    //  degrees:   0=este, 90=norte, 180=oeste, 270=sur
    //  elevation: 0=amanecer/ocaso, 90=mediodía (74º max. altitude in Spain's summer)

    // Orange 60% sat. (255 199 102 RGB)
    q3map_sunExt 1 0.780392 0.400000 150 160 25 0 0    // main Sun light
    q3map_sunExt 1 0.780392 0.400000 10 160 -25 0 0    // secondary Sun light for bottom of the map

    // Blue 80% sat. (51 107 255 RGB)
    q3map_lightImage env/sky/blue_color.jpg       // color sampling image, instead of skybox
    q3map_skyLight 35 6                           // <amount> <iterations> (Make surface to cast light)
}

// EOF ------------------------------- EOF --------------------------------- EOF
